@@ -32,7 +32,8 @@ from agml.synthetic.options import HeliosOptions
 from agml.synthetic.options import AnnotationType, SimulationType
 from agml.synthetic.config import load_default_helios_configuration, verify_helios
 from agml.synthetic.compilation import (
-    HELIOS_BUILD, HELIOS_EXECUTABLE, XML_PATH, PROJECT_PATH
+    HELIOS_BUILD, HELIOS_EXECUTABLE, XML_PATH, PROJECT_PATH,
+    recompile_helios, is_helios_compiled_with_lidar
 )
 from agml.synthetic.converter import HeliosDataFormatConverter
 from agml.utils.logging import log
@@ -42,7 +43,7 @@ from agml.utils.logging import log
 class GenerationInstanceOptions:
     canopy: str
     num_images: int
-    annotation_type: Union[AnnotationType, str]
+    annotation_type: List[Union[AnnotationType, str]]
     simulation_type: Union[SimulationType, str]
     labels: List[str]
     output_dir: str
@@ -52,7 +53,7 @@ class GenerationInstanceOptions:
             raise ValueError("The number of images cannot be negative.")
 
         try:
-            self.annotation_type = AnnotationType(self.annotation_type)
+            self.annotation_type = [AnnotationType(a) for a in self.annotation_type]
         except ValueError:
             raise ValueError(
                 "Expected either an `AnnotationType` parameter "
@@ -139,28 +140,6 @@ class HeliosDataGenerator(AgMLSerializable):
 
     def _convert_options_to_xml(self):
         """Converts the `HeliosOptions` parameters to XML format."""
-        # Convert all of the parameters to XML format.
-        tree = ET.parse(io.StringIO(dict2xml(
-            {'helios': self._prepare_parameters_for_generation()})))
-
-        # Update the camera tags.
-        root = tree.getroot()
-        for child in root:
-            if child.tag == 'camera_position':
-                child.tag = 'globaldata_vec3'
-                child.set('label', 'camera_position')
-            if child.tag == 'camera_lookat':
-                child.tag = 'globaldata_vec3'
-                child.set('label', 'camera_lookat')
-            if child.tag == 'image_resolution':
-                child.tag = 'globaldata_int2'
-                child.set('label', 'image_resolution')
-
-        # Return the modified tree.
-        return tree
-
-    def _prepare_parameters_for_generation(self):
-        """Prepares the provided Helios parameter options for generation."""
         parameters = self._options._to_dict()
 
         # Divide the image resolution in half. For some reason, Helios
@@ -174,6 +153,18 @@ class HeliosDataGenerator(AgMLSerializable):
         ground_params = self._load_ground_parameters()
         parameters['Ground'] = ground_params
 
+        # The `scan` tag is used for LiDAR generation. This must be added later
+        # because there can be multiple origins and thus multiple `scan` tags.
+        if self._generation_options.simulation_type == SimulationType.LiDAR or self._generation_options.simulation_type == SimulationType.Both:
+            scan_tags = []
+            if isinstance(parameters['lidar']['origin'][0], list):
+                for origin in parameters['lidar']['origin']:
+                    scan_tag = parameters['lidar']
+                    scan_tag['origin'] = origin
+                    scan_tags.append(scan_tag)
+            else:
+                scan_tags.append(parameters['lidar'])
+
         # Convert the canopy parameters to the Helios string format.
         self._convert_dict_params_to_string(parameters)
 
@@ -182,13 +173,36 @@ class HeliosDataGenerator(AgMLSerializable):
             self._canopy + "Parameters": parameters['canopy'],
             'Ground': parameters['Ground']}
         xml_params = {'canopygenerator': canopy_parameters}
-        if self._generation_options.simulation_type == 'lidar':
-            xml_params['scan'] = parameters['lidar']
-        else:
+        if self._generation_options.simulation_type == SimulationType.RGB or self._generation_options.simulation_type == SimulationType.Both:
             xml_params[''] = parameters['camera']
 
-        # Return the parsed dictionary.
-        return xml_params
+        # Convert all of the parameters to XML format.
+        tree = ET.parse(io.StringIO(dict2xml({'helios': xml_params})))
+        root = tree.getroot()
+
+        # Add the `scan` tags if necessary for LiDAR generation.
+        if self._generation_options.simulation_type == SimulationType.LiDAR or self._generation_options.simulation_type == SimulationType.Both:
+            for scan_tag in scan_tags: # noqa
+                scan_tag_contents = ET.parse(
+                    io.StringIO(dict2xml({'scan': scan_tag}))).getroot()
+                ET.indent(scan_tag_contents)
+                root.append(scan_tag_contents)
+
+        # Update the camera tags.
+        for child in root:
+            if child.tag == 'camera_position':
+                child.tag = 'globaldata_vec3'
+                child.set('label', 'camera_position')
+            if child.tag == 'camera_lookat':
+                child.tag = 'globaldata_vec3'
+                child.set('label', 'camera_lookat')
+            if child.tag == 'image_resolution':
+                child.tag = 'globaldata_int2'
+                child.set('label', 'image_resolution')
+
+        # Return the modified tree.
+        ET.indent(tree, '    ')
+        return tree
 
     @staticmethod
     def _convert_dict_params_to_string(d):
@@ -237,7 +251,7 @@ class HeliosDataGenerator(AgMLSerializable):
         # Construct the string with the output.
         xml_file = os.path.realpath(xml_file)
         cfg = f"{self._generation_options.num_images}\n" \
-              f"{self._generation_options.annotation_type.value}\n" \
+              f"{' '.join([i.value for i in self._generation_options.annotation_type])}\n" \
               f"{self._generation_options.simulation_type.value}\n" \
               f"{' '.join(self._generation_options.labels)}\n" \
               f"{xml_file}\n{self._generation_options.output_dir}"
@@ -290,7 +304,9 @@ class HeliosDataGenerator(AgMLSerializable):
         will be converted to COCO JSON, and the directory structure of the dataset
         will also be changed accordingly. If you want to maintain the integrity of
         the generated data for Helios, then you can provide the optional parameter
-        `convert_data = False`, which will leave data as generated by Helios.
+        `convert_data = False`, which will leave data as generated by Helios. Note that
+        if multiple annotation types are being generated at once, then you cannot
+        use data conversion into the AgML format.
 
         Regardless of whether annotations are converted to the AgML format from the
         Helios format, the output directory will contain an extra hidden directory
@@ -346,6 +362,7 @@ class HeliosDataGenerator(AgMLSerializable):
         else:
             output_dir = synthetic_data_save_path()
         output_dir = os.path.join(output_dir, name)
+        output_dir = os.path.abspath(output_dir)
         if os.path.exists(output_dir):
             self._parse_output_path(output_dir, clear_existing_files)
         else:
@@ -360,6 +377,12 @@ class HeliosDataGenerator(AgMLSerializable):
             simulation_type = self._options.simulation_type,
             labels = self._options.labels,
             output_dir = output_dir)
+        
+        # Recompile Helios with LiDAR capabilities if it is needed.
+        if self._options.simulation_type == SimulationType.LiDAR:
+            if not is_helios_compiled_with_lidar():
+                log("Recompiling Helios with LiDAR enabled.")
+                recompile_helios(lidar_enabled = True)
 
         # Create the output metadata directory.
         metadata_dir = os.path.join(output_dir, '.metadata')
@@ -374,7 +397,8 @@ class HeliosDataGenerator(AgMLSerializable):
         # Write the actual configuration file.
         cfg_file = os.path.join(PROJECT_PATH, f'config_{name}.txt')
         self._write_config(
-            cfg_file = cfg_file, xml_file = os.path.join(XML_PATH, xml_file_base))
+            cfg_file = cfg_file,
+            xml_file = os.path.join(XML_PATH, xml_file_base))
         self._write_config(
             cfg_file = os.path.join(metadata_dir, f'config_{name}.txt'),
             xml_file = os.path.join(metadata_dir, xml_file_base))
@@ -412,6 +436,12 @@ class HeliosDataGenerator(AgMLSerializable):
 
         # Convert the dataset format.
         if convert_data:
+            if len(self.options.annotation_type) > 1:
+                log("Cannot convert data into the AgML format for multiple annotation types.")
+                return
+            if self.options.simulation_type == SimulationType.LiDAR:
+                log("Cannot convert data into the AgML format for LiDAR simulations.")
+                return
             cvt = HeliosDataFormatConverter(output_dir)
             cvt.convert()
 
