@@ -49,8 +49,7 @@ def resolve_list_value(val):
 
 
 def resolve_tuple_values(*inputs, custom_error = None):
-    """Determines whether `inputs[0]` contains two values or
-    they are distributed amongst the values in `inputs`. """
+    """Determines whether values are distributed amongst the values in `inputs`. """
     if isinstance(inputs[0], (list, tuple)) and all(c is None for c in inputs[1:]):
         if len(inputs[0]) != len(inputs):
             # special case for COCO JSON
@@ -62,9 +61,8 @@ def resolve_tuple_values(*inputs, custom_error = None):
             if custom_error is not None:
                 raise ValueError(custom_error)
             else:
-                raise ValueError(
-                    f"Expected either a tuple with {len(inputs)} values "
-                    f"or {len(inputs)} values across two arguments.")
+                raise ValueError(f"Expected either a tuple with {len(inputs)} values "
+                                 f"or {len(inputs)} values across two arguments.")
         else:
             return inputs[0]
     return inputs
@@ -125,3 +123,48 @@ def shapes(seq):
         raise ValueError(f"One or more of the objects has no shape or length: {seq}.")
 
 
+def weak_squeeze(arr, ndims = 2):
+    """Performs a 'weak squeeze', adding a dimension back if necessary."""
+    if isinstance(arr, np.ndarray):
+        arr = np.squeeze(arr)
+        while arr.ndim < ndims:
+            arr = np.expand_dims(arr, axis = 0)
+    if isinstance(arr, list):
+        while len(arr) < ndims:
+            arr = [arr]
+    return arr
+
+
+def is_float(num):
+    """Determines if a number is a float."""
+    is_ = isinstance(num, float) or isinstance(num, np.float32) or isinstance(num, np.float64)
+    if is_: return True
+    try:
+        float(num)
+    except ValueError:
+        return False
+    return True
+
+
+def is_int(num):
+    """Determines if a number is an int."""
+    is_ = isinstance(num, int) or isinstance(num, np.int32) or isinstance(num, np.int64)
+    if is_: return True
+    try:
+        int(num)
+    except ValueError:
+        return False
+    return True
+
+
+def has_func(module, func):
+    """Determines if a module has a function."""
+    try:
+        return True
+    except ImportError:
+        return False
+
+
+def flatten(xss):
+    """Flatten a list of lists"""
+    return [x for xs in xss for x in xs]
